@@ -66,9 +66,7 @@ struct _CheeseWidgetPrivate
   GError *error;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (CheeseWidget, cheese_widget, GTK_TYPE_NOTEBOOK);
-
-void setup_camera (CheeseWidget *widget);
+G_DEFINE_TYPE_WITH_PRIVATE (CheeseWidget, cheese_widget, GTK_TYPE_NOTEBOOK)
 
 static GdkPixbuf *
 cheese_widget_load_pixbuf (GtkWidget  *widget,
@@ -174,7 +172,7 @@ static void
 cheese_widget_set_problem_page (CheeseWidget *widget,
                                 const char   *icon_name)
 {
-  CheeseWidgetPrivate *priv = widget->priv;
+    CheeseWidgetPrivate *priv = cheese_widget_get_instance_private (widget);
 
     priv->state = CHEESE_WIDGET_STATE_ERROR;
     g_object_notify_by_pspec (G_OBJECT (widget), properties[PROP_STATE]);
@@ -189,7 +187,7 @@ cheese_widget_set_problem_page (CheeseWidget *widget,
 static void
 cheese_widget_init (CheeseWidget *widget)
 {
-  CheeseWidgetPrivate *priv = widget->priv = cheese_widget_get_instance_private (widget);
+    CheeseWidgetPrivate *priv = cheese_widget_get_instance_private (widget);
   GtkWidget           *box;
   ClutterActor        *stage, *frame;
   ClutterColor black = { 0x00, 0x00, 0x00, 0xff };
@@ -243,7 +241,7 @@ cheese_widget_init (CheeseWidget *widget)
 static void
 cheese_widget_finalize (GObject *object)
 {
-  CheeseWidgetPrivate *priv = ((CheeseWidget *) object)->priv;
+    CheeseWidgetPrivate *priv = cheese_widget_get_instance_private (CHEESE_WIDGET (object));
 
   g_clear_object (&priv->settings);
   g_clear_object (&priv->webcam);
@@ -255,10 +253,12 @@ static void
 cheese_widget_get_property (GObject *object, guint prop_id,
                             GValue *value, GParamSpec *pspec)
 {
-  CheeseWidgetPrivate *priv = ((CheeseWidget *) object)->priv;
+    CheeseWidgetPrivate *priv;
 
   g_return_if_fail (CHEESE_IS_WIDGET (object));
 
+    priv = cheese_widget_get_instance_private (CHEESE_WIDGET (object));
+
   switch (prop_id)
   {
     case PROP_STATE:
@@ -294,60 +294,66 @@ webcam_state_changed (CheeseCamera *camera, GstState state,
     }
 }
 
-void
+static void
 setup_camera (CheeseWidget *widget)
 {
-  CheeseWidgetPrivate *priv = widget->priv;
-  gchar *webcam_device = NULL;
-  gint x_resolution;
-  gint y_resolution;
-  gdouble brightness;
-  gdouble contrast;
-  gdouble saturation;
-  gdouble hue;
+    CheeseWidgetPrivate *priv = cheese_widget_get_instance_private (widget);
+    gchar *webcam_device;
+    gint x_resolution;
+    gint y_resolution;
 
-  g_settings_get (priv->settings, "photo-x-resolution", "i", &x_resolution);
-  g_settings_get (priv->settings, "photo-y-resolution", "i", &y_resolution);
-  g_settings_get (priv->settings, "camera",       "s", &webcam_device);
-  g_settings_get (priv->settings, "brightness",   "d", &brightness);
-  g_settings_get (priv->settings, "contrast",     "d", &contrast);
-  g_settings_get (priv->settings, "saturation",   "d", &saturation);
-  g_settings_get (priv->settings, "hue",          "d", &hue);
+    x_resolution = g_settings_get_int (priv->settings, "photo-x-resolution");
+    y_resolution = g_settings_get_int (priv->settings, "photo-y-resolution");
+    webcam_device = g_settings_get_string (priv->settings, "camera");
 
-  priv->webcam = cheese_camera_new (CLUTTER_TEXTURE (priv->texture),
-                                    webcam_device,
-                                    x_resolution,
-                                    y_resolution);
+    priv->webcam = cheese_camera_new (CLUTTER_TEXTURE (priv->texture),
+                                      webcam_device, x_resolution,
+                                      y_resolution);
 
-  g_free (webcam_device);
+    g_free (webcam_device);
 
-  cheese_camera_setup (priv->webcam, NULL, &priv->error);
+    cheese_camera_setup (priv->webcam, NULL, &priv->error);
 
-  gtk_spinner_stop (GTK_SPINNER (priv->spinner));
+    gtk_spinner_stop (GTK_SPINNER (priv->spinner));
 
-  if (priv->error != NULL)
-  {
-    cheese_widget_set_problem_page (CHEESE_WIDGET (widget), "error");
-  }
-  else
-  {
-    cheese_camera_set_balance_property (priv->webcam, "brightness", brightness);
-    cheese_camera_set_balance_property (priv->webcam, "contrast", contrast);
-    cheese_camera_set_balance_property (priv->webcam, "saturation", saturation);
-    cheese_camera_set_balance_property (priv->webcam, "hue", hue);
-    priv->state = CHEESE_WIDGET_STATE_READY;
-    g_object_notify_by_pspec (G_OBJECT (widget), properties[PROP_STATE]);
-    g_signal_connect (priv->webcam, "state-flags-changed",
-                      G_CALLBACK (webcam_state_changed), widget);
-    cheese_camera_play (priv->webcam);
-    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), WEBCAM_PAGE);
-  }
+    if (priv->error != NULL)
+    {
+        cheese_widget_set_problem_page (CHEESE_WIDGET (widget), "error");
+    }
+    else
+    {
+        gdouble brightness;
+        gdouble contrast;
+        gdouble saturation;
+        gdouble hue;
+
+        brightness = g_settings_get_double (priv->settings, "brightness");
+        contrast = g_settings_get_double (priv->settings, "contrast");
+        saturation = g_settings_get_double (priv->settings, "saturation");
+        hue = g_settings_get_double (priv->settings, "hue");
+
+        cheese_camera_set_balance_property (priv->webcam, "brightness",
+                                            brightness);
+        cheese_camera_set_balance_property (priv->webcam, "contrast", contrast);
+        cheese_camera_set_balance_property (priv->webcam, "saturation",
+                                            saturation);
+        cheese_camera_set_balance_property (priv->webcam, "hue", hue);
+
+        priv->state = CHEESE_WIDGET_STATE_READY;
+        g_object_notify_by_pspec (G_OBJECT (widget), properties[PROP_STATE]);
+        g_signal_connect (priv->webcam, "state-flags-changed",
+                          G_CALLBACK (webcam_state_changed), widget);
+        cheese_camera_play (priv->webcam);
+        gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), WEBCAM_PAGE);
+    }
 }
 
 static void
 cheese_widget_realize (GtkWidget *widget)
 {
-  CheeseWidgetPrivate *priv = ((CheeseWidget *) widget)->priv;
+    CheeseWidgetPrivate *priv;
+
+    priv = cheese_widget_get_instance_private (CHEESE_WIDGET (widget));
 
   GTK_WIDGET_CLASS (cheese_widget_parent_class)->realize (widget);
 
@@ -370,9 +376,6 @@ cheese_widget_class_init (CheeseWidgetClass *klass)
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->finalize = cheese_widget_finalize;
-#if 0
-  object_class->set_property = cheese_widget_set_property;
-#endif
   object_class->get_property = cheese_widget_get_property;
   widget_class->realize      = cheese_widget_realize;
 
@@ -413,9 +416,13 @@ cheese_widget_new (void)
 GSettings *
 cheese_widget_get_settings (CheeseWidget *widget)
 {
+    CheeseWidgetPrivate *priv;
+
   g_return_val_if_fail (CHEESE_WIDGET (widget), NULL);
 
-  return widget->priv->settings;
+    priv = cheese_widget_get_instance_private (widget);
+
+    return priv->settings;
 }
 
 /*
@@ -427,9 +434,13 @@ cheese_widget_get_settings (CheeseWidget *widget)
 GObject *
 cheese_widget_get_camera (CheeseWidget *widget)
 {
+    CheeseWidgetPrivate *priv;
+
   g_return_val_if_fail (CHEESE_WIDGET (widget), NULL);
 
-  return G_OBJECT (widget->priv->webcam);
+    priv = cheese_widget_get_instance_private (widget);
+
+    return G_OBJECT (priv->webcam);
 }
 
 /*
@@ -441,9 +452,13 @@ cheese_widget_get_camera (CheeseWidget *widget)
 GtkWidget *
 cheese_widget_get_video_area (CheeseWidget *widget)
 {
+    CheeseWidgetPrivate *priv;
+
   g_return_val_if_fail (CHEESE_WIDGET (widget), NULL);
 
-  return widget->priv->screen;
+    priv = cheese_widget_get_instance_private (widget);
+
+    return priv->screen;
 }
 
 /**
@@ -463,7 +478,7 @@ cheese_widget_get_error (CheeseWidget *widget, GError **error)
 
   g_return_if_fail (CHEESE_WIDGET (widget));
 
-  priv = (widget)->priv;
+    priv = cheese_widget_get_instance_private (widget);
 
   g_propagate_error (error, priv->error);
 
